# OpenMesh, 8.0

[![](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/badges/master/pipeline.svg)](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/commits/master)


## Getting OpenMesh
All Documentation, binaries and original source code are available at www.openmesh.org  

The main git repository is available at:  
https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh.git  

The gitlab site can be found here:  
https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh  

The python bindings can be found here:    
https://www.graphics.rwth-aachen.de:9000/OpenMesh/openmesh-python

## Download Binaries

### Windows

| Visual Studio Version: | 2017 | 2015 |
| -------- | -------- |-------- |
| 64-Bit shared, with apps  | [Download](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/build-release?job=VS2017-64-bit-shared-apps) | [Download](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/build-release?job=VS2015-64-bit-shared-apps)  |
| 32-Bit shared, with apps   | -  | [Download](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/build-release?job=VS2015-32-bit-shared-apps)   |
| 64-Bit static, with apps  | [Download ](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/build-release?job=VS2017-64-bit-static-apps)  | [Download ](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/build-release?job=VS2015-64-bit-static-apps)  |
| 32-Bit static, with apps   | -  | [ Download ](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/build-release?job=VS2015-32-bit-static-apps)   |
| 64-Bit shared, no apps  | [Download](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/build-release?job=VS2017-64-bit-shared-no-apps)  | [Download](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/build-release?job=VS2015-64-bit-shared-no-apps)  |
| 32-Bit shared, no apps   | [Download](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/build-release?job=VS2017-32-bit-shared-no-apps)   | [Download](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/build-release?job=VS2015-32-bit-shared-no-apps)   |
| 64-Bit static, no apps  | [Download ](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/build-release?job=VS2017-64-bit-static-no-apps)   | [Download ](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/build-release?job=VS2015-64-bit-static-no-apps)  |
| 32-Bit static, no apps   | [ Download ](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/build-release?job=VS2017-32-bit-static-no-apps)  | [ Download ](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/build-release?job=VS2015-32-bit-static-no-apps)   |

## Download Sources
[ Download Sources](https://www.graphics.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse/?job=Sources )


## Installing
Unpack the tar-ball to a suitable place.  


A detailed build manual for Mac/Windows/Linux is in the Documentation   
located at Doc/html/index.html   

## Documentation

The latest Documentation can be found at:  
http://www.openmesh.org/media/Documentations/OpenMesh-Doc-Latest  

Documentation for previous versions is available on our website as well.  
